@@ -85,7 +85,7 @@ types_converter_dict = {
             "int8": "int",
             "int16": "int",
             "int32": "int",
-            "array(string)": "array[varchar]"
+            "array(string)": "array[varchar]",
         },
         "default": {},
     },
@@ -104,6 +104,24 @@ types_converter_dict = {
         },
         "default": {},
     },
+    # toDo remove default values if not cond, varchar(467) - remove numbers for ch
+    "pg:ch": {
+        "type": {
+            "_text": "Nullable(String)",
+            "text": "Nullable(String)",
+            "jsonb": "Nullable(String)",
+            "json": "Nullable(String)",
+            "varchar": "Nullable(String)",
+            "interval": "Nullable(String)",
+            "int2": "int2",
+            "boolean": "UInt8",
+            "int4": "int4",
+            "timestamp": "Datetime",
+            "int8": "int8",
+            "integer": "Int32",
+        },
+        "default": {"false": 0, "true": 1},
+    },
 }
 
 """
@@ -175,6 +193,12 @@ base_converter_params = {
             "blob": "json",
             "boolean": "bool",
         },
+        "from_python_dict": {
+            "str": "varchar(1000)",
+            "bool": "int",
+            "int": "int",
+            "float": "float",
+        },
     },
     "exasol": {
         "dialect": "exa+pyodbc",
