@@ -46,7 +46,7 @@ def get_default_arg_sql_alchemy(column):
 
 class DataBaseWorker:
     def __init__(
-            self, sql_credentials, db, debug=True, tables=None, table_checker=True
+        self, sql_credentials, db, debug=True, tables=None, table_checker=True
     ):
         """
         :param sql_credentials:
@@ -57,10 +57,12 @@ class DataBaseWorker:
         """
         self.table_checker = table_checker
         self.tables = tables or []
+        self.table_name = None
         self.db = db
         self.debug = debug
         self.sql_credentials = sql_credentials
         self.cred = self.sql_credentials[self.db]
+        self.conn = None
         if self.__check_dialect():
             uri_sql_alchemy = "{0}://{1}:{2}@{3}:{4}/{5}".format(
                 self.dialect,
@@ -83,6 +85,10 @@ class DataBaseWorker:
         self.conn = self.engine.connect()
         self.log("connecting is successfull")
 
+    def __del__(self):
+        if self.conn is not None:
+            self.conn.close()
+
     def __check_dialect(self):
         if self.db not in base_converter_params.keys():
             raise ModuleNotFoundError(
@@ -93,12 +99,15 @@ class DataBaseWorker:
         return True
 
     @property
-    def meta(self, tables=None):
+    def meta(self):
         if "schema" in self.cred:
             meta = MetaData(bind=self.engine, schema=self.schema)
         else:
             meta = MetaData(bind=self.engine)
-        tables = tables or self.tables
+        if self.table_name is None:
+            tables = self.tables
+        else:
+            tables = [self.table_name]
         if len(tables) > 0 and self.table_checker:
             try:
                 meta.reflect(only=tables)
@@ -149,9 +158,10 @@ class DataBaseWorker:
             )
         return True
 
-    def insert_vertica(self, table_name, data, schema=None):
+    def insert_vertica(self, table_name, data, schema=None, table_suffix=None):
         """
         custom insert for vertica using json
+        :param table_suffix: change table to insert
         :param schema:  schema to uplaad
         :param table_name:
         :param data: data to insert
@@ -166,7 +176,8 @@ class DataBaseWorker:
         keys_data = [key for key in keys_data if key in columns]
         for item in data:
             for key in keys_to_remove:
-                del item[key]
+                if key in item:
+                    del item[key]
         fields_json = [
             key
             for key in keys_data
@@ -174,21 +185,21 @@ class DataBaseWorker:
         ]
         vertica_insert(
             cursor=cursor,
-            target=(schema or self.schema) + "." + table_name,
+            target=(schema or self.schema) + "." + table_name + (table_suffix or ""),
             fields_json=fields_json,
             fields=keys_data,
             data=data,
         )
 
     def insert_merge_vertica(
-            self,
-            table_name,
-            data,
-            staging_schema=None,
-            schema=None,
-            staging_table_suffix=None,
-            key_fields=None,
-            filter_merge_fields=None,
+        self,
+        table_name,
+        data,
+        staging_schema=None,
+        schema=None,
+        staging_table_suffix=None,
+        key_fields=None,
+        filter_merge_fields=None,
     ):
         """
         Insert and update data in target table using temporary staging table, only for vertica
@@ -217,14 +228,21 @@ class DataBaseWorker:
         self.log(sql_create_staging)
         self.conn.execute(sql_create_staging)
         try:
-            self.insert_vertica(table_name, data, schema=staging_schema)
-            vertica_merge(
-                conn=self.conn,
-                table_name=schema + "." + table_name,
-                staging_table_name=staging_table_name,
-                fields=self.get_columns(table_name),
-                key_fields=key_fields,
-                filter_merge_fields=filter_merge_fields,
+            self.insert_vertica(
+                table_name,
+                data,
+                schema=staging_schema,
+                table_suffix=staging_table_suffix,
+            )
+            self.log(
+                vertica_merge(
+                    conn=self.conn,
+                    table_name=schema + "." + table_name,
+                    staging_table_name=staging_table_name,
+                    fields=self.get_columns(table_name),
+                    key_fields=key_fields,
+                    filter_merge_fields=filter_merge_fields,
+                )
             )
         finally:
             sql_drop = "drop table {staging_table_name} cascade".format(
@@ -240,7 +258,9 @@ class DataBaseWorker:
             "character_maximum_length",
             "column_default",
         ]
+        self.table_name = table_name
         table_sql = Table(table_name, self.meta)
+        self.table_name = None
         columns = [c.name for c in table_sql.columns]
         types = [get_type_sql_alchemy(c.type) for c in table_sql.columns]
         length = [get_length_type_sql_alchemy(c.type) for c in table_sql.columns]
