@@ -213,6 +213,4 @@ class FieldsConverter:
                 logging.info("creating table {} is successfull".format(table))
             if dir_ddl is not None:
                 save_ddl_to_file(sql=sql, table_name=table, ddl_dir=dir_ddl)
-        if to_create:  # refit meta
-            self.db_worker_to.init_meta()
         return result_list
