@@ -44,12 +44,20 @@ class FieldsConverterOneWay:
         :param debug: show debug text
         :param tables:  converter only for list of tables. Will process more rapid
         """
-        self.db_worker = DataBaseWorker(sql_credentials, db, debug, tables)
+        if sql_credentials is not None:
+            self.db_worker = DataBaseWorker(sql_credentials, db, debug, tables)
+        else:
+            self.db_worker = None
+        self.db = db
 
     @property
     def __str__(self):
         return "FieldsConverterOneWay_{}".format(self.db)
 
+    @property
+    def quote_char(self):
+        return base_converter_params[self.db]["quote"]
+
     @property
     def __repr__(self):
         return "FieldsConverterOneWay_{}".format(self.db)
@@ -68,7 +76,7 @@ class FieldsConverterOneWay:
         :return: type_python
         """
         type_python = "str"
-        update_types_dict = base_converter_params[self.db_worker.db]["to_python_dict"]
+        update_types_dict = base_converter_params[self.db]["to_python_dict"]
         for type_old in update_types_dict:
             if type_sql.lower().find(type_old) > -1:
                 type_python = update_types_dict[type_old]
@@ -81,7 +89,7 @@ class FieldsConverterOneWay:
         :param   type_
         :return: type_python
         """
-        update_types_dict = base_converter_params[self.db_worker.db]["from_python_dict"]
+        update_types_dict = base_converter_params[self.db]["from_python_dict"]
         type_sql = update_types_dict["str"]
         for type_old in update_types_dict:
             if type_python.lower().find(type_old) > -1:
@@ -91,6 +99,7 @@ class FieldsConverterOneWay:
 
     def update_value_df_type(self, table_name, dataframe, dict_replace_str={}):
         """
+        :param table_name:
         :param fields:
         :param dataframe:
         :param dict_replace_str:
@@ -128,7 +137,7 @@ class FieldsConverterOneWay:
             item[key] = float(item[key])
         elif type_python == "json":
             try:
-                item[key] = json.dumps(item[key])
+                item[key] = json.dumps(item[key], ensure_ascii=False)
             except (TypeError, ValueError):
                 item[key] = item[key]
         elif type_python == "bool":
@@ -141,30 +150,32 @@ class FieldsConverterOneWay:
                 )
         return item
 
-    def update_value_type(self, table_name, items, dict_replace_str={}):
+    def update_value_type(self, table_name, items, dict_replace_str={}, fields=None):
         """
+        :param fields:
         :param dict_replace_str: replace in string dict
         :param items: list of dicts to update
         :param table_name: table_name to insert
         :return: updated dictionary
         """
-        fields = self.db_worker.get_columns(table_name=table_name)
+        fields = fields or self.db_worker.get_columns(table_name=table_name)
         if len(fields) == 0:
             raise Exception("No table {} in metadata".format(table_name))
         keys = fields.keys()
         for item in items:
             for key in keys:
+
                 item = self.__update_value_type(
                     fields, item, key, dict_replace_str=dict_replace_str
                 )
         return items
 
     def create_table_from_python(
-            self, fields_python, table_name, to_create=True, ddl_dir=None
+            self, fields_python, table_name, to_create=True, ddl_dir=None, schema=None
     ):
         """create tables using python types"""
         txt = "\n\nCREATE TABLE {schema}.{table} (".format(
-            schema=self.schema, table=table_name
+            schema=schema or self.schema, table=table_name
         )
         res_list = []
         for field in fields_python:
@@ -175,7 +186,29 @@ class FieldsConverterOneWay:
         txt += ")"
         if to_create:
             self.conn.execute(txt)
-            logging.info("creating table {} is successfull".format(table_name))
+            logging.info("creating table {} is successful".format(table_name))
         if ddl_dir is not None:
             save_ddl_to_file(ddl=txt, ddl_dir=ddl_dir, table_name=table_name)
         return txt
+
+    def create_table_from_dataframe(
+            self, dataframe, table_name, to_create=True, ddl_dir=None, schema=None
+    ):
+        """create tables using python types"""
+        txt = "\n\nCREATE TABLE {schema}.{table} (".format(
+            schema=schema or self.schema, table=table_name
+        )
+        fields_python = dataframe.dtypes.apply(lambda x: x.name).to_dict()
+        res_list = []
+        for field in fields_python:
+            type_python = fields_python[field]
+            type_sql = self.__get_sql_type(type_python)
+            res_list.append(self.quote_char + field + self.quote_char + " " + type_sql)
+        txt += ",\n".join(res_list)
+        txt += ")"
+        if to_create:
+            self.conn.execute(txt)
+            logging.info("creating table {} is successful".format(table_name))
+        if ddl_dir is not None:
+            save_ddl_to_file(ddl=txt, ddl_dir=ddl_dir, table_name=table_name)
+        return txt
\ No newline at end of file
