@@ -14,7 +14,7 @@ def write_list_as_json_str(fields_json, rows):
                         r[field_json] = json.loads(r[field_json])
                     except TypeError:
                         continue
-    return "\n".join([json.dumps(dict(r), default=myconverter) or "{}" for r in rows])
+    return "\n".join([json.dumps(dict(r), default=myconverter, ensure_ascii=False) or "{}" for r in rows])
 
 
 def vertica_insert(cursor, target, fields, fields_json, data):
@@ -25,3 +25,4 @@ def vertica_insert(cursor, target, fields, fields_json, data):
     data_str = write_list_as_json_str(fields_json, data)
     cursor.copy(copy_statement, data_str)
     cursor.close()
+
